@@ -40,12 +40,6 @@ class Container(object):
     @type cdn_ttl: number
     @ivar cdn_log_retention: retention of the logs in the container.
     @type cdn_log_retention: bool
-    @ivar cdn_acl_user_agent: enable ACL restriction by User Agent
-    for this container.
-    @type cdn_acl_user_agent: str
-    @ivar cdn_acl_referrer: enable ACL restriction by Referrer
-    for this container.
-    @type cdn_acl_referrer: str
 
     @undocumented: _fetch_cdn_data
     @undocumented: _list_objects_raw
@@ -76,10 +70,11 @@ class Container(object):
         self.object_count = count
         self.size_used = size
         self.cdn_uri = None
+        self.cdn_ssl_uri = None
+        self.cdn_streaming_uri = None
         self.cdn_ttl = None
         self.cdn_log_retention = None
-        self.cdn_acl_user_agent = None
-        self.cdn_acl_referrer = None
+
         if connection.cdn_enabled:
             self._fetch_cdn_data()
 
@@ -89,18 +84,18 @@ class Container(object):
         Fetch the object's CDN data from the CDN service
         """
         response = self.conn.cdn_request('HEAD', [self.name])
-        if (response.status >= 200) and (response.status < 300):
+        if response.status >= 200 and response.status < 300:
             for hdr in response.getheaders():
                 if hdr[0].lower() == 'x-cdn-uri':
                     self.cdn_uri = hdr[1]
                 if hdr[0].lower() == 'x-ttl':
                     self.cdn_ttl = int(hdr[1])
+                if hdr[0].lower() == 'x-cdn-ssl-uri':
+                    self.cdn_ssl_uri = hdr[1]
+                if hdr[0].lower() == 'x-cdn-streaming-uri':
+                    self.cdn_streaming_uri = hdr[1]
                 if hdr[0].lower() == 'x-log-retention':
                     self.cdn_log_retention = hdr[1] == "True" and True or False
-                if hdr[0].lower() == 'x-user-agent-acl':
-                    self.cdn_acl_user_agent = hdr[1]
-                if hdr[0].lower() == 'x-referrer-acl':
-                    self.cdn_acl_referrer = hdr[1]
 
     @requires_name(InvalidContainerName)
     def make_public(self, ttl=consts.default_cdn_ttl):
@@ -146,52 +141,44 @@ class Container(object):
             raise ResponseError(response.status, response.reason)
 
     @requires_name(InvalidContainerName)
-    def acl_user_agent(self, cdn_acl_user_agent=consts.cdn_acl_user_agent):
+    def purge_from_cdn(self, email=None):
         """
-        Enable ACL restriction by User Agent for this container.
+        Purge Edge cache for all object inside of this container.
+        You will be notified by email if one is provided when the
+        job completes.
 
-        >>> container.acl_user_agent("Mozilla")
+        >>> container.purge_from_cdn("user@dmain.com")
+        
+        or
 
-        @param cdn_acl_user_agent: Set the user agent ACL
-        @type cdn_acl_user_agent: str
+        >>> container.purge_from_cdn("user@domain.com,user2@domain.com")
+        
+        or
+        
+        >>> container.purge_from_cdn()
+        
+        @param email: A Valid email address
+        @type email: str
         """
         if not self.conn.cdn_enabled:
             raise CDNNotEnabled()
 
-        hdrs = {'X-User-Agent-ACL': cdn_acl_user_agent}
-        response = self.conn.cdn_request('POST', [self.name], hdrs=hdrs)
+        if email:
+            hdrs = {"X-Purge-Email": email}
+            response = self.conn.cdn_request('DELETE', [self.name], hdrs=hdrs)
+        else:
+            response = self.conn.cdn_request('DELETE', [self.name])
+
         if (response.status < 200) or (response.status >= 300):
             raise ResponseError(response.status, response.reason)
 
-        self.cdn_acl_user_agent = cdn_acl_user_agent
-
-    @requires_name(InvalidContainerName)
-    def acl_referrer(self, cdn_acl_referrer=consts.cdn_acl_referrer):
-        """
-        Enable ACL restriction by referrer for this container.
-
-        >>> container.acl_referrer("http://www.example.com")
-
-        @param cdn_acl_user_agent: Set the referrer ACL
-        @type cdn_acl_user_agent: str
-        """
-        if not self.conn.cdn_enabled:
-            raise CDNNotEnabled()
-
-        hdrs = {'X-Referrer-ACL': cdn_acl_referrer}
-        response = self.conn.cdn_request('POST', [self.name], hdrs=hdrs)
-        if (response.status < 200) or (response.status >= 300):
-            raise ResponseError(response.status, response.reason)
-
-        self.cdn_acl_referrer = cdn_acl_referrer
-
     @requires_name(InvalidContainerName)
     def log_retention(self, log_retention=consts.cdn_log_retention):
         """
         Enable CDN log retention on the container. If enabled logs will be
         periodically (at unpredictable intervals) compressed and uploaded to
         a ".CDN_ACCESS_LOGS" container in the form of
-        "container_name.YYYYMMDDHH-XXXX.gz". Requires CDN be enabled on the
+        "container_name/YYYY/MM/DD/HH/XXXX.gz". Requires CDN be enabled on the
         account.
 
         >>> container.log_retention(True)
@@ -243,6 +230,38 @@ class Container(object):
             raise ContainerNotPublic()
         return self.cdn_uri
 
+    @requires_name(InvalidContainerName)
+    def public_ssl_uri(self):
+        """
+        Return the SSL URI for this container, if it is publically
+        accessible via the CDN.
+
+        >>> connection['container1'].public_ssl_uri()
+        'https://c61.ssl.cf0.rackcdn.com'
+
+        @rtype: str
+        @return: the public SSL URI for this container
+        """
+        if not self.is_public():
+            raise ContainerNotPublic()
+        return self.cdn_ssl_uri
+
+    @requires_name(InvalidContainerName)
+    def public_streaming_uri(self):
+        """
+        Return the Streaming URI for this container, if it is publically
+        accessible via the CDN.
+
+        >>> connection['container1'].public_ssl_uri()
+        'https://c61.stream.rackcdn.com'
+
+        @rtype: str
+        @return: the public Streaming URI for this container
+        """
+        if not self.is_public():
+            raise ContainerNotPublic()
+        return self.cdn_streaming_uri
+
     @requires_name(InvalidContainerName)
     def create_object(self, object_name):
         """
