@@ -75,6 +75,7 @@ class Object(object):
         self.container = container
         self.last_modified = None
         self.metadata = {}
+        self.manifest = None
         if object_record:
             self.name = object_record['name']
             self.content_type = object_record['content_type']
@@ -231,6 +232,29 @@ class Object(object):
             if response.status != 202:
                 raise ResponseError(response.status, response.reason)
 
+    @requires_name(InvalidObjectName)
+    def sync_manifest(self):
+        """
+        Commits the manifest to the remote storage system.
+
+        >>> test_object = container['paradise_lost.pdf']
+        >>> test_object.manifest = 'container/prefix'
+        >>> test_object.sync_manifest()
+
+        Object manifests can be set and retrieved through the object's
+        .manifest attribute.
+        """
+        self._name_check()
+        if self.manifest:
+            headers = self._make_headers()
+            headers['Content-Length'] = "0"
+            response = self.container.conn.make_request(
+                'PUT', [self.container.name, self.name], hdrs=headers,
+                data='')
+            response.read()
+            if response.status < 200 or response.status > 299:
+                raise ResponseError(response.status, response.reason)
+
     def __get_conn_for_write(self):
         headers = self._make_headers()
 
@@ -289,9 +313,13 @@ class Object(object):
             except IOError:
                 pass  # If the file descriptor is read-only this will fail
             self.size = int(os.fstat(data.fileno())[6])
-        else:
+        elif isinstance(data, basestring):
             data = StringIO.StringIO(data)
             self.size = data.len
+        elif isinstance(data, StringIO.StringIO):
+            self.size = data.len
+        else:
+            self.size = len(data)
 
         # If override is set (and _etag is not None), then the etag has
         # been manually assigned and we will not calculate our own.
@@ -359,7 +387,7 @@ class Object(object):
             self._etag = None
 
         headers = self._make_headers()
-        headers['Destination'] = "%s/%s" % (container_name, name)
+        headers['Destination'] = quote("%s/%s" % (container_name, name))
         headers['Content-Length'] = 0
         response = self.container.conn.make_request(
                    'COPY', [self.container.name, self.name], hdrs=headers, data='')
@@ -387,7 +415,7 @@ class Object(object):
             self._etag = None
 
         headers = self._make_headers()
-        headers['X-Copy-From'] = "%s/%s" % (container_name, name)
+        headers['X-Copy-From'] = quote("%s/%s" % (container_name, name))
         headers['Content-Length'] = 0
         response = self.container.conn.make_request(
                    'PUT', [self.container.name, self.name], hdrs=headers, data='')
@@ -433,6 +461,10 @@ class Object(object):
         """
         self._name_check()
 
+        if isinstance(iterable, basestring):
+            # use write to buffer the string and avoid sending it 1 byte at a time
+            self.write(iterable)
+
         if hasattr(iterable, 'read'):
 
             def file_iterator(file):
@@ -529,6 +561,8 @@ class Object(object):
         if (response.status < 200) or (response.status > 299):
             raise ResponseError(response.status, response.reason)
         for hdr in response.getheaders():
+            if hdr[0].lower() == 'x-object-manifest':
+                self.manifest = hdr[1]
             if hdr[0].lower() == 'content-type':
                 self.content_type = hdr[1]
             if hdr[0].lower().startswith('x-object-meta-'):
@@ -560,6 +594,8 @@ class Object(object):
         headers['Content-Length'] = (str(self.size) \
                                           and str(self.size) != "0") \
                                           and str(self.size) or "0"
+        if self.manifest:
+            headers['X-Object-Manifest'] = self.manifest
         if self._etag:
             headers['ETag'] = self._etag
 
@@ -620,6 +656,22 @@ class Object(object):
         return "%s/%s" % (self.container.public_ssl_uri().rstrip('/'),
                 quote(self.name))
 
+    def public_streaming_uri(self):
+        """
+        Retrieve the streaming URI for this object, if its container is public.
+
+        >>> container1 = connection['container1']
+        >>> container1.make_public()
+        >>> container1.create_object('file.txt').write('testing')
+        >>> container1['file.txt'].public_streaming_uri()
+        'https://c61.stream.rackcdn.com/file.txt'
+
+        @return: the public Streaming URI for this object
+        @rtype: str
+        """
+        return "%s/%s" % (self.container.public_streaming_uri().rstrip('/'),
+                quote(self.name))
+
     def purge_from_cdn(self, email=None):
         """
         Purge Edge cache for this object.
